==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/test/java/de/fzj/unicore/ucc/actions/TestTDGeneration.java <==
package de.fzj.unicore.ucc.actions;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.util.Properties;

import org.junit.Test;

import xmlbeans.org.oasis.saml2.assertion.AssertionDocument;
import de.fzj.unicore.wsrflite.security.ISecurityProperties;
import de.fzj.unicore.wsrflite.security.UASSecurityProperties;
import eu.unicore.bugsreporter.annotation.FunctionalTest;

public class TestTDGeneration{

	@FunctionalTest(id="testGetTD", description="Test SAML assertion generation command using a pem file")
	@Test
	public void testGenTD()throws Exception{
		IssueTD u=new IssueTD();
		u.setSecurityProperties(makeSecurityProperties());
		File f=new File("target","test.td");
		f.deleteOnExit();
		String[] args=new String[]{"issue-delegation",
				"-f","src/test/resources/certs/server.pem",
				"-t",f.getAbsolutePath(),
				"-V","1"};
		u.init(args);
		u.process();
		assertTrue(f.exists());
		//check we can read
		AssertionDocument td=AssertionDocument.Factory.parse(f);
		assertNotNull(td);
		System.out.println(td);
	}

	@FunctionalTest(id="testGetTDUsingDN", description="Test SAML assertion generation command using DN file")
	@Test
	public void testGenTDUsingDN()throws Exception{
		IssueTD u=new IssueTD();
		u.setSecurityProperties(makeSecurityProperties());
		File f=new File("target","test.td");
		f.deleteOnExit();
		String[] args=new String[]{"issue-delegation",
				"-S","CN=Somebody",
				"-t",f.getAbsolutePath(),
				"-V","1"};
		u.init(args);
		u.process();
		assertTrue(f.exists());
		//check we can read
		AssertionDocument td=AssertionDocument.Factory.parse(f);
		assertNotNull(td);
		assertTrue(String.valueOf(td).contains("CN=Somebody"));
		
	}

	//programatically setup security
	protected ISecurityProperties makeSecurityProperties() throws Exception {
		Properties p = new Properties();
		String certs="src/test/resources/certs";

		p.setProperty(ISecurityProperties.WSRF_SSL,"true");
		p.setProperty(ISecurityProperties.WSRF_SSL_CLIENTAUTH,"true");
		p.setProperty(ISecurityProperties.WSRF_SSL_KEYSTORE,certs+"/user-keystore.jks");
		p.setProperty(ISecurityProperties.WSRF_SSL_KEYTYPE,"JKS");
		p.setProperty(ISecurityProperties.WSRF_SSL_KEYALIAS,"demo user");
		p.setProperty(ISecurityProperties.WSRF_SSL_KEYPASS,"the!user");
		p.setProperty(ISecurityProperties.WSRF_SSL_TRUSTPASS,"the!user");
		p.setProperty(ISecurityProperties.WSRF_SSL_TRUSTSTORE,certs+"/user-keystore.jks");
		p.setProperty(ISecurityProperties.WSRF_SSL_TRUSTTYPE,"JKS");
		return new UASSecurityProperties(new Properties(), p);
	}

	
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/test/java/de/fzj/unicore/ucc/actions/TestTDGeneration.java <==
package de.fzj.unicore.ucc.actions;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.File;

import org.junit.Test;

import xmlbeans.org.oasis.saml2.assertion.AssertionDocument;
import eu.emi.security.authn.x509.impl.KeystoreCertChainValidator;
import eu.emi.security.authn.x509.impl.KeystoreCredential;
import eu.unicore.bugsreporter.annotation.FunctionalTest;
import eu.unicore.util.httpclient.DefaultClientConfiguration;
import eu.unicore.util.httpclient.IClientConfiguration;

public class TestTDGeneration{

	@FunctionalTest(id="testGetTD", description="Test SAML assertion generation command using a pem file")
	@Test
	public void testGenTD()throws Exception{
		IssueTD u=new IssueTD();
		u.setSecurityProperties(makeSecurityProperties());
		File f=new File("target","test.td");
		f.deleteOnExit();
		String[] args=new String[]{"issue-delegation",
				"-f","src/test/resources/certs/server.pem",
				"-t",f.getAbsolutePath(),
				"-V","1"};
		u.init(args);
		u.process();
		assertTrue(f.exists());
		//check we can read
		AssertionDocument td=AssertionDocument.Factory.parse(f);
		assertNotNull(td);
		System.out.println(td);
	}

	@FunctionalTest(id="testGetTDUsingDN", description="Test SAML assertion generation command using DN file")
	@Test
	public void testGenTDUsingDN()throws Exception{
		IssueTD u=new IssueTD();
		u.setSecurityProperties(makeSecurityProperties());
		File f=new File("target","test.td");
		f.deleteOnExit();
		String[] args=new String[]{"issue-delegation",
				"-S","CN=Somebody",
				"-t",f.getAbsolutePath(),
				"-V","1"};
		u.init(args);
		u.process();
		assertTrue(f.exists());
		//check we can read
		AssertionDocument td=AssertionDocument.Factory.parse(f);
		assertNotNull(td);
		assertTrue(String.valueOf(td).contains("CN=Somebody"));
		
	}

	//programatically setup security
	protected IClientConfiguration makeSecurityProperties() throws Exception {
		String certs="src/test/resources/certs/user-keystore.jks";
		DefaultClientConfiguration secP=new DefaultClientConfiguration();
		secP.setSslEnabled(true);
		secP.setSslAuthn(true);
		secP.setDoSignMessage(true);
		secP.setValidator(new KeystoreCertChainValidator(certs, 
				"the!user".toCharArray(), "jks", -1));
		secP.setCredential(new KeystoreCredential(certs, 
				"the!user".toCharArray(), "the!user".toCharArray(), "demo user", "jks"));
		return secP;
	}
}
